/**
 *  @filename   :   epaper-test-warntafel.ino
 *  @brief      :   7.5inch e-paper display an mega2560
 *  
 *  based on Waveshare Demo Software for Arduino and STM32
 *  
  */
#include <SPI.h>
#include <SD.h>
#include "epd7in5b_HD.h"

void printDirectory(File dir, int numTabs);

Epd epd;
File root; 
File dataFile;

void setup() 
{
  Serial1.begin(115200);
  Serial1.setTimeout(60000);  // 60 sekunden wartezeit
  // SPI SDCard init zuerst!
  if (!SD.begin(4)) 
  {
    Serial1.println("initialization failed!");
    return;
  }

  // SPI Display Init danach
  if (epd.Init() != 0) 
  {
    Serial1.print("e-Paper init failed");
    return;
  }
  delay(2000);
  Serial1.println("Initialisierung abgeschlossen");
  Serial1.println("Display steuern mit:");
  Serial1.println("d oder D fuer loeschen");
  Serial1.println("l oder L fuer Image Liste ausgeben");
  Serial1.println("r oder R fuer rotes Image ausgeben");
  Serial1.println("s oder S fuer schwarzes Image ausgeben");
}

void loop() 
{
  int incomingByte = 0; // for incoming seria1 data
  String filename;
  
  if (Serial1.available() > 0) 
  {
    incomingByte = Serial1.read();
    switch(incomingByte)
    {
      case 'd':
      case 'D':
        Serial1.println("");
        Serial1.println("Display loeschen");
        epd.Clear();
        Serial1.println("Fertig");
        break;

      case 'l':
      case 'L':
        Serial1.println("");
        Serial1.println("Dateien:");
        root = SD.open("/");
        printDirectory(root, 0);
        Serial1.println("Fertig");
        break;

      case 'r':
      case 'R':
        Serial1.println("");
        Serial1.println("Dateinamen fuer Rot eingeben:");
        filename = Serial1.readString();
        filename.toUpperCase();
        dataFile = SD.open(filename);
        if (dataFile) 
        {
          Serial1.print("Schreibe Daten Rot ");
          Serial1.println(filename);
          epd.WriteRedImage();
          while (dataFile.available()) 
          {
            epd.SendData(dataFile.read());
          }
          dataFile.close();
          epd.TurnOnDisplay();
          Serial1.println("Fertig");
        }
        else
        {
          Serial1.print("Datei nicht gefunden : ");
          Serial1.println(filename);
          Serial1.println("Fertig");
        }
        break;

      case 's':
      case 'S':
        Serial1.println("");
        Serial1.println("Dateinamen fuer Schwarz eingeben:");
        filename = Serial1.readString();
        filename.toUpperCase();
        dataFile = SD.open(filename);
        if (dataFile) 
        {
          Serial1.print("Schreibe Daten Schwarz ");
          Serial1.println(filename);
          epd.WriteBlackImage();
          while (dataFile.available()) 
          {
            epd.SendData(~dataFile.read());
          }
          dataFile.close();
          epd.TurnOnDisplay();
          Serial1.println("Fertig");
        }
        else
        {
          Serial1.print("Datei nicht gefunden : ");
          Serial1.println(filename);
          Serial1.println("Fertig");
        }
        break;

      default:
        Serial1.println("");
        Serial1.write(incomingByte);
        Serial1.println(" Das Kommando kenne ich leider nicht");
        Serial1.println("Fertig");
        break;
    }
  }
}

void printDirectory(File dir, int numTabs) 
{
  while (true) 
  {
    File entry =  dir.openNextFile();
    if (! entry) 
    {
      // no more files
      break;
    }
    for (uint8_t i = 0; i < numTabs; i++) 
    {
      Serial1.print('\t');
    }
    Serial1.print(entry.name());
    if (entry.isDirectory()) 
    {
      Serial1.println("/");
      printDirectory(entry, numTabs + 1);
    } 
    else 
    {
      // files have sizes, directories do not
      Serial1.print("\t\t");
      Serial1.println(entry.size(), DEC);
    }
    entry.close();
  }
}
