/**
 *  @filename   :   epd7in5b.h
 *  @brief      :   Header file for e-paper library epd7in5b.cpp
 *  
 *  based on Waveshare Demo Software for Arduino and STM32
 *  
 */

#ifndef EPD7IN5B_HD_H
#define EPD7IN5B_HD_H

#include "epdif.h"

// Display resolution
#define EPD_WIDTH       880
#define EPD_HEIGHT      528
#define EPD_HEIGHT2     150

// Display Commands
#define GATE_SETTING                             0x01
#define SET_GATE_DRIVING_VOLTAGE                 0x03
#define SET_SOURCE_DRIVING_VOLTAGE               0x04
#define SET_SCANNING_START_GATE_DRIVER           0x0F
#define DEEP_SLEEP_MODE_CONTROL                  0x10
#define DATA_ENTRY_SEQUENCE                      0x11
#define SW_RESET                                 0x12
#define HV_READY_DETECTION                       0x14
#define VCI_DETECTION                            0x15
#define TEMPERATURE_SENSOR_SELECTION             0x18
#define WRITE_TEMPERATURE_REGISTER               0x1A
#define READ_TEMPERATURE_REGISTER                0x1B
#define WRITE_CMD_TO_EXTERNAL_TEMPERATURE_SENSOR 0x1C
#define ACTIVATE_DISPLAY_UPDATE_SEQUENCE         0x20
#define DISPLAY_UPDATE_CONTROL1                  0x21
#define DISPLAY_UPDATE_CONTROL2                  0x22
#define WRITE_RAM_BW                             0x24
#define WRITE_RAM_RED                            0x26
#define READ_RAM                                 0x27
#define VCOM_SENSE                               0x28
#define VCOM_SENSE_DURATION                      0x29
#define PROG_VCOM_OTP                            0x2A
#define WRITE_VCOM_CONTROL                       0x2B
#define WRITE_VCOM                               0x2C
#define DISPLAY_OTP_READ                         0x2D
#define OTP_CRC                                  0x34
#define OTP_CRC_STATUS_READ                      0x35
#define OTP_PROGRAM_SELECTION                    0x36
#define DISPLAY_OPTION_WRITE                     0x37
#define USERID_WRITE                             0x38
#define BORDER_WAVEFORM_CONTROL                  0x3C
#define READ_RAM_OPTION                          0x41
#define SET_RAM_X_POS_START_END                  0x44
#define SET_RAM_Y_POS_START_END                  0x45
#define AUTO_WRITE_RED_RAM                       0x46
#define AUTO_WRITE_BW_RAM                        0x47
#define SET_RAM_X_ADDRESS_COUNTER                0x4E
#define SET_RAM_Y_ADDRESS_COUNTER                0x4F
#define DISPLAY_NOP                              0x7F

class Epd : EpdIf 
{
public:
    unsigned long width;
    unsigned long height;

    Epd();
    ~Epd();
    int  Init(void);
    void WaitUntilIdle(void);
    void Reset(void);
    void Clear(void);
    void TurnOnDisplay(void);
    void WriteBlackImage(void);
    void WriteRedImage(void);
    void DisplayBlackImage(const uint8_t *blackimage,uint32_t start_X, uint32_t start_Y, uint32_t image_width, uint32_t image_high);
    void DisplayRedImage(const uint8_t *image,uint32_t start_X, uint32_t start_Y, uint32_t image_width, uint32_t image_high);
    void Display(const uint8_t *blackimage);
    void DisplayPictureFromRAM(const uint8_t *image, uint8_t Block);
    void SendCommand(unsigned char command);
    void SendData(unsigned char data);
    void Sleep(void);
private:
    unsigned int reset_pin;
    unsigned int dc_pin;
    unsigned int cs_pin;
    unsigned int busy_pin;
};

#endif /* EPD7IN5B_H */

/* END OF FILE */
